/*
 * Copyright © 2024-2025 Apple Inc. and the Pkl project authors. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.pkl.cli.repl

private val cmdRegex = Regex(":(\\p{Alpha}*)(\\p{Space}*)(.*)", RegexOption.DOT_MATCHES_ALL)

internal fun getMatchingCommands(input: String): List<ParsedCommand> {
  val match = cmdRegex.matchEntire(input) ?: return listOf()
  val (cmd, ws, arg) = match.destructured
  return Command.entries
    .filter { it.toString().lowercase().startsWith(cmd) }
    .map { ParsedCommand(it, cmd, ws, arg) }
}

internal data class ParsedCommand(
  val type: Command,
  val cmd: String,
  val ws: String,
  val arg: String,
)

internal enum class Command {
  Clear,
  Examples,
  Force,
  Help,
  Load,
  Quit,
  Reset;

  override fun toString() = name.lowercase()
}
